@@ -23,7 +23,7 @@
 (defun destroy-process (process)
   #+cmu (mp:destroy-process process)
   #+allegro (mp:process-kill process)
-  #+sb-thread (sb-thread:destroy-thread process)
+  #+sb-thread (sb-thread:terminate-thread process)
   #+lispworks (mp:process-kill process)
   #+ccl (ccl:process-kill process)
   )
@@ -80,6 +80,3 @@
   "Put thread to sleep for n seconds."
   #+allegro (mp:process-sleep n)
   #-allegro (sleep n))
-
-
-
